```{include} ../README.md
:relative-docs: docs/
:relative-images:
```

## Data process graph

Graph of the data process, automatically derived from the code itself.

```{include} dag.md
:alt: Data process graph
```

## Highlighted bubbles

Overlay of the external contours corresponding to bubbles in one frame of a high-speed video. Represents output from the "fill" step of the data process.

```{image} _static/multicolor.png
:alt: Bubbles highlighted with different colors
:width: 360px
:align: center
```

```{toctree}
:hidden:
changelog
```
